@@ -17,14 +17,17 @@
 
 #include <limits.h>
 #include <stdarg.h>
-#include <string.h>
 
 #include "bson-compat.h"
-#include "bson-config.h"
 #include "bson-string.h"
 #include "bson-memory.h"
 #include "bson-utf8.h"
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#else
+#include <string.h>
+#endif
 
 /*
  *--------------------------------------------------------------------------
@@ -59,11 +62,11 @@ bson_string_new (const char *str) /* IN */
    bson_string_t *ret;
 
    ret = bson_malloc0 (sizeof *ret);
-   ret->len = str ? (int)strlen (str) : 0;
+   ret->len = str ? (int) strlen (str) : 0;
    ret->alloc = ret->len + 1;
 
    if (!bson_is_power_of_two (ret->alloc)) {
-      ret->alloc = (uint32_t)bson_next_power_of_two ((size_t)ret->alloc);
+      ret->alloc = (uint32_t) bson_next_power_of_two ((size_t) ret->alloc);
    }
 
    BSON_ASSERT (ret->alloc >= 1);
@@ -73,9 +76,9 @@ bson_string_new (const char *str) /* IN */
    if (str) {
       memcpy (ret->str, str, ret->len);
    }
-   ret->str [ret->len] = '\0';
+   ret->str[ret->len] = '\0';
 
-   ret->str [ret->len] = '\0';
+   ret->str[ret->len] = '\0';
 
    return ret;
 }
@@ -102,8 +105,8 @@ bson_string_new (const char *str) /* IN */
  */
 
 char *
-bson_string_free (bson_string_t *string,       /* IN */
-                  bool           free_segment) /* IN */
+bson_string_free (bson_string_t *string, /* IN */
+                  bool free_segment)     /* IN */
 {
    char *ret = NULL;
 
@@ -139,26 +142,27 @@ bson_string_free (bson_string_t *string,       /* IN */
 
 void
 bson_string_append (bson_string_t *string, /* IN */
-                    const char    *str)    /* IN */
+                    const char *str)       /* IN */
 {
    uint32_t len;
 
    BSON_ASSERT (string);
    BSON_ASSERT (str);
 
-   len = (uint32_t)strlen (str);
+   len = (uint32_t) strlen (str);
 
    if ((string->alloc - string->len - 1) < len) {
       string->alloc += len;
       if (!bson_is_power_of_two (string->alloc)) {
-         string->alloc = (uint32_t)bson_next_power_of_two ((size_t)string->alloc);
+         string->alloc =
+            (uint32_t) bson_next_power_of_two ((size_t) string->alloc);
       }
       string->str = bson_realloc (string->str, string->alloc);
    }
 
    memcpy (string->str + string->len, str, len);
    string->len += len;
-   string->str [string->len] = '\0';
+   string->str[string->len] = '\0';
 }
 
 
@@ -183,21 +187,21 @@ bson_string_append (bson_string_t *string, /* IN */
 
 void
 bson_string_append_c (bson_string_t *string, /* IN */
-                      char           c)      /* IN */
+                      char c)                /* IN */
 {
    char cc[2];
 
    BSON_ASSERT (string);
 
    if (BSON_UNLIKELY (string->alloc == (string->len + 1))) {
-      cc [0] = c;
-      cc [1] = '\0';
+      cc[0] = c;
+      cc[1] = '\0';
       bson_string_append (string, cc);
       return;
    }
 
-   string->str [string->len++] = c;
-   string->str [string->len] = '\0';
+   string->str[string->len++] = c;
+   string->str[string->len] = '\0';
 }
 
 
@@ -218,11 +222,11 @@ bson_string_append_c (bson_string_t *string, /* IN */
  */
 
 void
-bson_string_append_unichar (bson_string_t  *string,  /* IN */
-                            bson_unichar_t  unichar) /* IN */
+bson_string_append_unichar (bson_string_t *string,  /* IN */
+                            bson_unichar_t unichar) /* IN */
 {
    uint32_t len;
-   char str [8];
+   char str[8];
 
    BSON_ASSERT (string);
    BSON_ASSERT (unichar);
@@ -230,7 +234,7 @@ bson_string_append_unichar (bson_string_t  *string,  /* IN */
    bson_utf8_from_unichar (unichar, str, &len);
 
    if (len <= 6) {
-      str [len] = '\0';
+      str[len] = '\0';
       bson_string_append (string, str);
    }
 }
@@ -253,9 +257,7 @@ bson_string_append_unichar (bson_string_t  *string,  /* IN */
  */
 
 void
-bson_string_append_printf (bson_string_t *string,
-                           const char    *format,
-                           ...)
+bson_string_append_printf (bson_string_t *string, const char *format, ...)
 {
    va_list args;
    char *ret;
@@ -292,7 +294,7 @@ bson_string_append_printf (bson_string_t *string,
 
 void
 bson_string_truncate (bson_string_t *string, /* IN */
-                      uint32_t       len)    /* IN */
+                      uint32_t len)          /* IN */
 {
    uint32_t alloc;
 
@@ -306,14 +308,14 @@ bson_string_truncate (bson_string_t *string, /* IN */
    }
 
    if (!bson_is_power_of_two (alloc)) {
-      alloc = (uint32_t)bson_next_power_of_two ((size_t)alloc);
+      alloc = (uint32_t) bson_next_power_of_two ((size_t) alloc);
    }
 
    string->str = bson_realloc (string->str, alloc);
    string->alloc = alloc;
    string->len = len;
 
-   string->str [string->len] = '\0';
+   string->str[string->len] = '\0';
 }
 
 
@@ -343,7 +345,7 @@ bson_strdup (const char *str) /* IN */
       return NULL;
    }
 
-   len = (long)strlen (str);
+   len = (long) strlen (str);
    out = bson_malloc (len + 1);
 
    if (!out) {
@@ -374,7 +376,7 @@ bson_strdup (const char *str) /* IN */
 
 char *
 bson_strdupv_printf (const char *format, /* IN */
-                     va_list     args)   /* IN */
+                     va_list args)       /* IN */
 {
    va_list my_args;
    char *buf;
@@ -456,8 +458,8 @@ bson_strdup_printf (const char *format, /* IN */
  */
 
 char *
-bson_strndup (const char *str,     /* IN */
-              size_t      n_bytes) /* IN */
+bson_strndup (const char *str, /* IN */
+              size_t n_bytes)  /* IN */
 {
    char *ret;
 
@@ -493,8 +495,8 @@ bson_strfreev (char **str) /* IN */
    int i;
 
    if (str) {
-      for (i = 0; str [i]; i++)
-         bson_free (str [i]);
+      for (i = 0; str[i]; i++)
+         bson_free (str[i]);
       bson_free (str);
    }
 }
@@ -517,8 +519,8 @@ bson_strfreev (char **str) /* IN */
  */
 
 size_t
-bson_strnlen (const char *s,      /* IN */
-              size_t      maxlen) /* IN */
+bson_strnlen (const char *s, /* IN */
+              size_t maxlen) /* IN */
 {
 #ifdef BSON_HAVE_STRNLEN
    return strnlen (s, maxlen);
@@ -526,7 +528,7 @@ bson_strnlen (const char *s,      /* IN */
    size_t i;
 
    for (i = 0; i < maxlen; i++) {
-      if (s [i] == '\0') {
+      if (s[i] == '\0') {
          return i;
       }
    }
@@ -556,9 +558,9 @@ bson_strnlen (const char *s,      /* IN */
  */
 
 void
-bson_strncpy (char       *dst,  /* IN */
-              const char *src,  /* IN */
-              size_t      size) /* IN */
+bson_strncpy (char *dst,       /* IN */
+              const char *src, /* IN */
+              size_t size)     /* IN */
 {
 #ifdef _MSC_VER
    strncpy_s (dst, size, src, _TRUNCATE);
@@ -592,32 +594,32 @@ bson_strncpy (char       *dst,  /* IN */
  */
 
 int
-bson_vsnprintf (char       *str,    /* IN */
-                size_t      size,   /* IN */
+bson_vsnprintf (char *str,          /* IN */
+                size_t size,        /* IN */
                 const char *format, /* IN */
-                va_list     ap)     /* IN */
+                va_list ap)         /* IN */
 {
-#ifdef BSON_OS_WIN32
+#ifdef _MSC_VER
    int r = -1;
 
    BSON_ASSERT (str);
 
    if (size != 0) {
-       r = _vsnprintf_s (str, size, _TRUNCATE, format, ap);
+      r = _vsnprintf_s (str, size, _TRUNCATE, format, ap);
    }
 
    if (r == -1) {
       r = _vscprintf (format, ap);
    }
 
-   str [size - 1] = '\0';
+   str[size - 1] = '\0';
 
    return r;
 #else
    int r;
 
    r = vsnprintf (str, size, format, ap);
-   str [size - 1] = '\0';
+   str[size - 1] = '\0';
    return r;
 #endif
 }
@@ -646,8 +648,8 @@ bson_vsnprintf (char       *str,    /* IN */
  */
 
 int
-bson_snprintf (char       *str,    /* IN */
-               size_t      size,   /* IN */
+bson_snprintf (char *str,          /* IN */
+               size_t size,        /* IN */
                const char *format, /* IN */
                ...)
 {
@@ -672,15 +674,19 @@ bson_snprintf (char       *str,    /* IN */
  *       A portable strtoll.
  *
  *       Convert a string to a 64-bit signed integer according to the given
- *       @base, which must be 16, 10, or 8. Leading whitespace will be ignord.
+ *       @base, which must be 16, 10, or 8. Leading whitespace will be ignored.
+ *
+ *       If base is 0 is passed in, the base is inferred from the string's
+ *       leading characters. Base-16 numbers start with "0x" or "0X", base-8
+ *       numbers start with "0", base-10 numbers start with a digit from 1 to 9.
  *
  *       If @e is not NULL, it will be assigned the address of the first invalid
  *       character of @s, or its null terminating byte if the entire string was
  *       valid.
  *
  *       If an invalid value is encountered, errno will be set to EINVAL and
- *       zero will be returned. This function does not currently detect values
- *       that are out of range.
+ *       zero will be returned. If the number is out of range, errno is set to
+ *       ERANGE and LLONG_MAX or LLONG_MIN is returned.
  *
  * Returns:
  *       The result of the conversion.
@@ -692,127 +698,121 @@ bson_snprintf (char       *str,    /* IN */
  */
 
 int64_t
-bson_ascii_strtoll (const char  *s,
-                    char       **e,
-                    int          base)
+bson_ascii_strtoll (const char *s, char **e, int base)
 {
-    char *tok = (char *)s;
-    char c;
-    int64_t number = 0;
-    int64_t sign = 1;
+   char *tok = (char *) s;
+   char *digits_start;
+   char c;
+   int64_t number = 0;
+   int64_t sign = 1;
+   int64_t cutoff;
+   int64_t cutlim;
 
-    if (!s) {
-       errno = EINVAL;
-       return 0;
-    }
+   errno = 0;
 
-    c = *tok;
+   if (!s) {
+      errno = EINVAL;
+      return 0;
+   }
 
-    while (isspace (c)) {
-        c = *++tok;
-    }
+   c = *tok;
 
-    if (!isdigit (c) && (c != '+') && (c != '-')) {
-        if (e != NULL) {
-           *e = tok - 1;
-        }
-        errno = EINVAL;
-        return 0;
-    }
+   while (isspace (c)) {
+      c = *++tok;
+   }
 
-    if (c == '-') {
-        sign = -1;
-        c = *++tok;
-    }
+   if (c == '-') {
+      sign = -1;
+      c = *++tok;
+   } else if (c == '+') {
+      c = *++tok;
+   } else if (!isdigit (c)) {
+      errno = EINVAL;
+      return 0;
+   }
 
-    if (c == '+') {
-        c = *++tok;
-    }
+   /* from here down, inspired by NetBSD's strtoll */
+   if ((base == 0 || base == 16) && c == '0' &&
+       (tok[1] == 'x' || tok[1] == 'X')) {
+      tok += 2;
+      c = *tok;
+      base = 16;
+   }
 
-    if (c == '0' && tok[1] != '\0' &&
-       (isdigit (tok[1]) || tok[1] == 'x' || tok[1] == 'X')) {
-        /* Hex, octal or decimal */
+   if (base == 0) {
+      base = c == '0' ? 8 : 10;
+   }
 
-        c = *++tok;
+   /* Cutoff is the greatest magnitude we'll be able to multiply by base without
+    * range error. If the current number is past cutoff and we see valid digit,
+    * fail. If the number is *equal* to cutoff, then the next digit must be less
+    * than cutlim, otherwise fail.
+    */
+   cutoff = sign == -1 ? INT64_MIN : INT64_MAX;
+   cutlim = (int) (cutoff % base);
+   cutoff /= base;
+   if (sign == -1) {
+      if (cutlim > 0) {
+         cutlim -= base;
+         cutoff += 1;
+      }
+      cutlim = -cutlim;
+   }
 
-        if (c == 'x' || c == 'X') { /* Hex */
-            if (base != 16 && base != 0) {
-                if (e != NULL) {
-                   *e = (char *)(s);
-                }
-                errno = EINVAL;
-                return 0;
-            }
+   digits_start = tok;
 
-            c = *++tok;
-            if (!isxdigit (c)) {
-                if (e != NULL) {
-                   *e = tok;
-                }
-                errno = EINVAL;
-                return 0;
-            }
-            do {
-                number = (number << 4) + (c - '0');
-                c = *(++tok);
-            } while (isxdigit (c));
-        }
-        else { /* Octal or Decimal -- prefixed with 0 */
-            if (base != 8 && base != 0 && base != 10) {
-                if (e != NULL) {
-                   *e = (char *)(s);
-                }
-                errno = EINVAL;
-                return 0;
-            }
-            if (base == 10) {
-                do {
-                  number = (number * 10) + (c - '0');
-                  c = *(++tok);
-                } while (isdigit (c));
-            } else { /*Octal*/
-                if ( c < '0' || c >= '8') {
-                  if (e != NULL) {
-                     *e = tok;
-                  }
-                  errno = EINVAL;
-                  return 0;
-                }
-                do {
-                  number = (number << 3) + (c - '0');
-                  c = *(++tok);
-                } while (('0' <= c) && (c < '8'));
-            }
-        }
+   while ((c = *tok)) {
+      if (isdigit (c)) {
+         c -= '0';
+      } else if (isalpha (c)) {
+         c -= isupper (c) ? 'A' - 10 : 'a' - 10;
+      } else {
+         /* end of number string */
+         break;
+      }
 
-        while (c == 'l' || c == 'L' || c == 'u' || c == 'U') {
-            c = *++tok;
-        }
-    }
-    else {
-        /* Decimal */
-        if (base != 10) {
-            if (e != NULL) {
-               *e = (char *)(s);
-            }
-            errno = EINVAL;
-            return 0;
-        }
+      if (c >= base) {
+         break;
+      }
 
-        do {
-            number = (number * 10) + (c - '0');
-            c = *(++tok);
-        } while (isdigit (c));
+      if (sign == -1) {
+         if (number < cutoff || (number == cutoff && c > cutlim)) {
+            number = INT64_MIN;
+            errno = ERANGE;
+            break;
+         } else {
+            number *= base;
+            number -= c;
+         }
+      } else {
+         if (number > cutoff || (number == cutoff && c > cutlim)) {
+            number = INT64_MAX;
+            errno = ERANGE;
+            break;
+         } else {
+            number *= base;
+            number += c;
+         }
+      }
 
-        while (c == 'l' || c == 'L' || c == 'u' || c == 'U') {
-            c = *(++tok);
-        }
-    }
+      tok++;
+   }
 
-    if (e != NULL) {
-       *e = tok;
-    }
-    errno = 0;
-    return (sign * number);
+   /* did we parse any digits at all? */
+   if (e != NULL && tok > digits_start) {
+      *e = tok;
+   }
+
+   return number;
 }
 
+
+int
+bson_strcasecmp (const char *s1, const char *s2)
+{
+#ifdef BSON_OS_WIN32
+   return _stricmp (s1, s2);
+#else
+   return strcasecmp (s1, s2);
+#endif
+}
