@@ -31,6 +31,10 @@
 #endif
 
 
+/* CDRIVER-2460 ensure the unused old BSON_ASSERT_STATIC macro still compiles */
+BSON_STATIC_ASSERT (1 == 1);
+
+
 static bson_t *
 get_bson (const char *filename)
 {
@@ -516,6 +520,21 @@ test_bson_append_dbpointer (void)
    bson_oid_t oid;
    bson_t *b;
    bson_t *b2;
+   uint8_t malformed_data[] = {
+      0x0C,
+      0x00,
+      0x00,
+      0x00, /* document length (12) */
+      0x0C, /* dbpointer type */
+      0x00, /* empty string key */
+      0x04,
+      0x00,
+      0x00,
+      0x00, /* string length (4). This is OOB. */
+      0x00, /* empty string */
+      0x00  /* end of document */
+   };
+   size_t error_offset = 0;
 
    b = bson_new ();
    bson_oid_init_from_string (&oid, "0123abcd0123abcd0123abcd");
@@ -524,6 +543,12 @@ test_bson_append_dbpointer (void)
    BSON_ASSERT_BSON_EQUAL (b, b2);
    bson_destroy (b);
    bson_destroy (b2);
+
+   b = bson_new_from_data (malformed_data, sizeof (malformed_data));
+   BSON_ASSERT (b);
+   BSON_ASSERT (!bson_validate (b, BSON_VALIDATE_NONE, &error_offset));
+   BSON_ASSERT (error_offset == 6);
+   bson_destroy (b);
 }
 
 
@@ -1167,7 +1192,7 @@ test_bson_validate (void)
       "test43.bson", BSON_VALIDATE_NONE, 6, BSON_VALIDATE_NONE, "corrupt BSON");
    VALIDATE_TEST ("test44.bson",
                   BSON_VALIDATE_NONE,
-                  24,
+                  6,
                   BSON_VALIDATE_NONE,
                   "corrupt BSON");
    VALIDATE_TEST (
@@ -2212,6 +2237,26 @@ test_bson_subtype_2 (void)
    bson_destroy (bson_ok);
 }
 
+/* CDRIVER-2455 Off-by-one error while appending regex */
+void
+test_bson_regex_lengths (void)
+{
+    bson_t new = BSON_INITIALIZER;
+    bson_oid_t oid;
+
+    bson_oid_init_from_string (&oid, "1234567890abcdef12345678");
+    bson_append_oid (&new, "0123456", -1, &oid);
+
+    bson_append_regex (&new,
+        "0_________1_________2_________3___4", -1,
+        "0_________1_________2_________3_________4_________5___4", "i");
+
+    ASSERT (new.len == 121);
+    ASSERT (new.flags & BSON_FLAG_STATIC);
+    ASSERT (!(new.flags & BSON_FLAG_INLINE));
+
+    bson_destroy(&new);
+}
 
 void
 test_bson_install (TestSuite *suite)
@@ -2296,5 +2341,6 @@ test_bson_install (TestSuite *suite)
                   "/bson/unsupported_type/empty_key",
                   test_bson_visit_unsupported_type_empty_key);
    TestSuite_Add (suite, "/bson/binary_subtype_2", test_bson_subtype_2);
+   TestSuite_Add (suite, "/bson/regex_length", test_bson_regex_lengths);
    TestSuite_Add (suite, "/util/next_power_of_two", test_next_power_of_two);
 }
